# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: epl/protobuf/v1/query.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='epl/protobuf/v1/query.proto',
  package='epl.protobuf.v1',
  syntax='proto3',
  serialized_options=b'\n\023com.epl.protobuf.v1B\nQueryProtoP\001Z.github.com/geo-grpc/api/golang/epl/protobuf/v1\242\002\003QPB',
  serialized_pb=b'\n\x1b\x65pl/protobuf/v1/query.proto\x12\x0f\x65pl.protobuf.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc0\x01\n\x0b\x46loatFilter\x12\x35\n\x08rel_type\x18\x02 \x01(\x0e\x32#.epl.protobuf.v1.FilterRelationship\x12\x0f\n\x05value\x18\x01 \x01(\x02H\x00\x12\x0f\n\x05start\x18\x03 \x01(\x02H\x00\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x02\x12\x36\n\x0esort_direction\x18\x05 \x01(\x0e\x32\x1e.epl.protobuf.v1.SortDirection\x12\x0b\n\x03set\x18\x06 \x03(\x02\x42\x06\n\x04\x64\x61ta\"\xc1\x01\n\x0c\x44oubleFilter\x12\x35\n\x08rel_type\x18\x02 \x01(\x0e\x32#.epl.protobuf.v1.FilterRelationship\x12\x0f\n\x05value\x18\x01 \x01(\x01H\x00\x12\x0f\n\x05start\x18\x03 \x01(\x01H\x00\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x01\x12\x36\n\x0esort_direction\x18\x05 \x01(\x0e\x32\x1e.epl.protobuf.v1.SortDirection\x12\x0b\n\x03set\x18\x06 \x03(\x01\x42\x06\n\x04\x64\x61ta\"\x8b\x02\n\x0fTimestampFilter\x12\x35\n\x08rel_type\x18\x02 \x01(\x0e\x32#.epl.protobuf.v1.FilterRelationship\x12+\n\x05value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12+\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\'\n\x03\x65nd\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x0esort_direction\x18\x05 \x01(\x0e\x32\x1e.epl.protobuf.v1.SortDirectionB\x06\n\x04\x64\x61ta\"\xc1\x01\n\x0cUInt32Filter\x12\x35\n\x08rel_type\x18\x02 \x01(\x0e\x32#.epl.protobuf.v1.FilterRelationship\x12\x0f\n\x05value\x18\x01 \x01(\rH\x00\x12\x0f\n\x05start\x18\x03 \x01(\rH\x00\x12\x0b\n\x03\x65nd\x18\x04 \x01(\r\x12\x36\n\x0esort_direction\x18\x05 \x01(\x0e\x32\x1e.epl.protobuf.v1.SortDirection\x12\x0b\n\x03set\x18\x06 \x03(\rB\x06\n\x04\x64\x61ta\"a\n\x0cStringFilter\x12\r\n\x05value\x18\x01 \x01(\t\x12\x35\n\x08rel_type\x18\x02 \x01(\x0e\x32#.epl.protobuf.v1.FilterRelationship\x12\x0b\n\x03set\x18\x06 \x03(\t*2\n\rSortDirection\x12\x0e\n\nNOT_SORTED\x10\x00\x12\x08\n\x04\x44\x45SC\x10\x01\x12\x07\n\x03\x41SC\x10\x02*\x96\x01\n\x12\x46ilterRelationship\x12\x06\n\x02\x45Q\x10\x00\x12\x07\n\x03LTE\x10\x02\x12\x07\n\x03GTE\x10\x04\x12\x06\n\x02LT\x10\x08\x12\x06\n\x02GT\x10\x10\x12\x0b\n\x07\x42\x45TWEEN\x10 \x12\x0f\n\x0bNOT_BETWEEN\x10@\x12\x08\n\x03NEQ\x10\x80\x01\x12\x07\n\x02IN\x10\x80\x02\x12\x0b\n\x06NOT_IN\x10\x80\x04\x12\t\n\x04LIKE\x10\x80\x08\x12\r\n\x08NOT_LIKE\x10\x80\x10\x42Y\n\x13\x63om.epl.protobuf.v1B\nQueryProtoP\x01Z.github.com/geo-grpc/api/golang/epl/protobuf/v1\xa2\x02\x03QPBb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_SORTDIRECTION = _descriptor.EnumDescriptor(
  name='SortDirection',
  full_name='epl.protobuf.v1.SortDirection',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_SORTED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DESC', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASC', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1037,
  serialized_end=1087,
)
_sym_db.RegisterEnumDescriptor(_SORTDIRECTION)

SortDirection = enum_type_wrapper.EnumTypeWrapper(_SORTDIRECTION)
_FILTERRELATIONSHIP = _descriptor.EnumDescriptor(
  name='FilterRelationship',
  full_name='epl.protobuf.v1.FilterRelationship',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQ', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LTE', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GTE', index=2, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LT', index=3, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GT', index=4, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BETWEEN', index=5, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_BETWEEN', index=6, number=64,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEQ', index=7, number=128,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IN', index=8, number=256,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_IN', index=9, number=512,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIKE', index=10, number=1024,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_LIKE', index=11, number=2048,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1090,
  serialized_end=1240,
)
_sym_db.RegisterEnumDescriptor(_FILTERRELATIONSHIP)

FilterRelationship = enum_type_wrapper.EnumTypeWrapper(_FILTERRELATIONSHIP)
NOT_SORTED = 0
DESC = 1
ASC = 2
EQ = 0
LTE = 2
GTE = 4
LT = 8
GT = 16
BETWEEN = 32
NOT_BETWEEN = 64
NEQ = 128
IN = 256
NOT_IN = 512
LIKE = 1024
NOT_LIKE = 2048



_FLOATFILTER = _descriptor.Descriptor(
  name='FloatFilter',
  full_name='epl.protobuf.v1.FloatFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rel_type', full_name='epl.protobuf.v1.FloatFilter.rel_type', index=0,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='epl.protobuf.v1.FloatFilter.value', index=1,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='epl.protobuf.v1.FloatFilter.start', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='epl.protobuf.v1.FloatFilter.end', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_direction', full_name='epl.protobuf.v1.FloatFilter.sort_direction', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set', full_name='epl.protobuf.v1.FloatFilter.set', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='epl.protobuf.v1.FloatFilter.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=82,
  serialized_end=274,
)


_DOUBLEFILTER = _descriptor.Descriptor(
  name='DoubleFilter',
  full_name='epl.protobuf.v1.DoubleFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rel_type', full_name='epl.protobuf.v1.DoubleFilter.rel_type', index=0,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='epl.protobuf.v1.DoubleFilter.value', index=1,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='epl.protobuf.v1.DoubleFilter.start', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='epl.protobuf.v1.DoubleFilter.end', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_direction', full_name='epl.protobuf.v1.DoubleFilter.sort_direction', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set', full_name='epl.protobuf.v1.DoubleFilter.set', index=5,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='epl.protobuf.v1.DoubleFilter.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=277,
  serialized_end=470,
)


_TIMESTAMPFILTER = _descriptor.Descriptor(
  name='TimestampFilter',
  full_name='epl.protobuf.v1.TimestampFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rel_type', full_name='epl.protobuf.v1.TimestampFilter.rel_type', index=0,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='epl.protobuf.v1.TimestampFilter.value', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='epl.protobuf.v1.TimestampFilter.start', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='epl.protobuf.v1.TimestampFilter.end', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_direction', full_name='epl.protobuf.v1.TimestampFilter.sort_direction', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='epl.protobuf.v1.TimestampFilter.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=473,
  serialized_end=740,
)


_UINT32FILTER = _descriptor.Descriptor(
  name='UInt32Filter',
  full_name='epl.protobuf.v1.UInt32Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rel_type', full_name='epl.protobuf.v1.UInt32Filter.rel_type', index=0,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='epl.protobuf.v1.UInt32Filter.value', index=1,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='epl.protobuf.v1.UInt32Filter.start', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='epl.protobuf.v1.UInt32Filter.end', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_direction', full_name='epl.protobuf.v1.UInt32Filter.sort_direction', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set', full_name='epl.protobuf.v1.UInt32Filter.set', index=5,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='epl.protobuf.v1.UInt32Filter.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=743,
  serialized_end=936,
)


_STRINGFILTER = _descriptor.Descriptor(
  name='StringFilter',
  full_name='epl.protobuf.v1.StringFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='epl.protobuf.v1.StringFilter.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rel_type', full_name='epl.protobuf.v1.StringFilter.rel_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set', full_name='epl.protobuf.v1.StringFilter.set', index=2,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=938,
  serialized_end=1035,
)

_FLOATFILTER.fields_by_name['rel_type'].enum_type = _FILTERRELATIONSHIP
_FLOATFILTER.fields_by_name['sort_direction'].enum_type = _SORTDIRECTION
_FLOATFILTER.oneofs_by_name['data'].fields.append(
  _FLOATFILTER.fields_by_name['value'])
_FLOATFILTER.fields_by_name['value'].containing_oneof = _FLOATFILTER.oneofs_by_name['data']
_FLOATFILTER.oneofs_by_name['data'].fields.append(
  _FLOATFILTER.fields_by_name['start'])
_FLOATFILTER.fields_by_name['start'].containing_oneof = _FLOATFILTER.oneofs_by_name['data']
_DOUBLEFILTER.fields_by_name['rel_type'].enum_type = _FILTERRELATIONSHIP
_DOUBLEFILTER.fields_by_name['sort_direction'].enum_type = _SORTDIRECTION
_DOUBLEFILTER.oneofs_by_name['data'].fields.append(
  _DOUBLEFILTER.fields_by_name['value'])
_DOUBLEFILTER.fields_by_name['value'].containing_oneof = _DOUBLEFILTER.oneofs_by_name['data']
_DOUBLEFILTER.oneofs_by_name['data'].fields.append(
  _DOUBLEFILTER.fields_by_name['start'])
_DOUBLEFILTER.fields_by_name['start'].containing_oneof = _DOUBLEFILTER.oneofs_by_name['data']
_TIMESTAMPFILTER.fields_by_name['rel_type'].enum_type = _FILTERRELATIONSHIP
_TIMESTAMPFILTER.fields_by_name['value'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMESTAMPFILTER.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMESTAMPFILTER.fields_by_name['end'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMESTAMPFILTER.fields_by_name['sort_direction'].enum_type = _SORTDIRECTION
_TIMESTAMPFILTER.oneofs_by_name['data'].fields.append(
  _TIMESTAMPFILTER.fields_by_name['value'])
_TIMESTAMPFILTER.fields_by_name['value'].containing_oneof = _TIMESTAMPFILTER.oneofs_by_name['data']
_TIMESTAMPFILTER.oneofs_by_name['data'].fields.append(
  _TIMESTAMPFILTER.fields_by_name['start'])
_TIMESTAMPFILTER.fields_by_name['start'].containing_oneof = _TIMESTAMPFILTER.oneofs_by_name['data']
_UINT32FILTER.fields_by_name['rel_type'].enum_type = _FILTERRELATIONSHIP
_UINT32FILTER.fields_by_name['sort_direction'].enum_type = _SORTDIRECTION
_UINT32FILTER.oneofs_by_name['data'].fields.append(
  _UINT32FILTER.fields_by_name['value'])
_UINT32FILTER.fields_by_name['value'].containing_oneof = _UINT32FILTER.oneofs_by_name['data']
_UINT32FILTER.oneofs_by_name['data'].fields.append(
  _UINT32FILTER.fields_by_name['start'])
_UINT32FILTER.fields_by_name['start'].containing_oneof = _UINT32FILTER.oneofs_by_name['data']
_STRINGFILTER.fields_by_name['rel_type'].enum_type = _FILTERRELATIONSHIP
DESCRIPTOR.message_types_by_name['FloatFilter'] = _FLOATFILTER
DESCRIPTOR.message_types_by_name['DoubleFilter'] = _DOUBLEFILTER
DESCRIPTOR.message_types_by_name['TimestampFilter'] = _TIMESTAMPFILTER
DESCRIPTOR.message_types_by_name['UInt32Filter'] = _UINT32FILTER
DESCRIPTOR.message_types_by_name['StringFilter'] = _STRINGFILTER
DESCRIPTOR.enum_types_by_name['SortDirection'] = _SORTDIRECTION
DESCRIPTOR.enum_types_by_name['FilterRelationship'] = _FILTERRELATIONSHIP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FloatFilter = _reflection.GeneratedProtocolMessageType('FloatFilter', (_message.Message,), {
  'DESCRIPTOR' : _FLOATFILTER,
  '__module__' : 'epl.protobuf.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.FloatFilter)
  })
_sym_db.RegisterMessage(FloatFilter)

DoubleFilter = _reflection.GeneratedProtocolMessageType('DoubleFilter', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLEFILTER,
  '__module__' : 'epl.protobuf.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.DoubleFilter)
  })
_sym_db.RegisterMessage(DoubleFilter)

TimestampFilter = _reflection.GeneratedProtocolMessageType('TimestampFilter', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMPFILTER,
  '__module__' : 'epl.protobuf.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.TimestampFilter)
  })
_sym_db.RegisterMessage(TimestampFilter)

UInt32Filter = _reflection.GeneratedProtocolMessageType('UInt32Filter', (_message.Message,), {
  'DESCRIPTOR' : _UINT32FILTER,
  '__module__' : 'epl.protobuf.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.UInt32Filter)
  })
_sym_db.RegisterMessage(UInt32Filter)

StringFilter = _reflection.GeneratedProtocolMessageType('StringFilter', (_message.Message,), {
  'DESCRIPTOR' : _STRINGFILTER,
  '__module__' : 'epl.protobuf.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.v1.StringFilter)
  })
_sym_db.RegisterMessage(StringFilter)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from epl.protobuf.v1 import geometry_pb2 as epl_dot_protobuf_dot_v1_dot_geometry__pb2


class GeometryServiceStub(object):
    """
    gRPC Interfaces for working with geometry operators
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Operate = channel.unary_unary(
                '/epl.protobuf.v1.GeometryService/Operate',
                request_serializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryRequest.SerializeToString,
                response_deserializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.FromString,
                )
        self.OperateBiStream = channel.stream_stream(
                '/epl.protobuf.v1.GeometryService/OperateBiStream',
                request_serializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryRequest.SerializeToString,
                response_deserializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.FromString,
                )
        self.OperateBiStreamFlow = channel.stream_stream(
                '/epl.protobuf.v1.GeometryService/OperateBiStreamFlow',
                request_serializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryRequest.SerializeToString,
                response_deserializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.FromString,
                )
        self.OperateServerStream = channel.unary_stream(
                '/epl.protobuf.v1.GeometryService/OperateServerStream',
                request_serializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryRequest.SerializeToString,
                response_deserializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.FromString,
                )
        self.OperateClientStream = channel.stream_unary(
                '/epl.protobuf.v1.GeometryService/OperateClientStream',
                request_serializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryRequest.SerializeToString,
                response_deserializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.FromString,
                )
        self.FileOperateBiStreamFlow = channel.stream_stream(
                '/epl.protobuf.v1.GeometryService/FileOperateBiStreamFlow',
                request_serializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.FileRequestChunk.SerializeToString,
                response_deserializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.FromString,
                )


class GeometryServiceServicer(object):
    """
    gRPC Interfaces for working with geometry operators
    """

    def Operate(self, request, context):
        """Execute a single blocking geometry operation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OperateBiStream(self, request_iterator, context):
        """stream in operator requests and get back a stream of results
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OperateBiStreamFlow(self, request_iterator, context):
        """manual flow control bi-directional stream. example
        go shouldn't use this because of https://groups.google.com/forum/#!topic/grpc-io/6_B46Oszb4k ?
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OperateServerStream(self, request, context):
        """Maybe a cut operation that returns a lot of different geometries? for now, this is not implemented.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OperateClientStream(self, request_iterator, context):
        """Maybe something like a union operation. for now, this is not implemented.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FileOperateBiStreamFlow(self, request_iterator, context):
        """stream in file chunks for a geometry file type and stream back results for each geometry encountered
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GeometryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Operate': grpc.unary_unary_rpc_method_handler(
                    servicer.Operate,
                    request_deserializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryRequest.FromString,
                    response_serializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.SerializeToString,
            ),
            'OperateBiStream': grpc.stream_stream_rpc_method_handler(
                    servicer.OperateBiStream,
                    request_deserializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryRequest.FromString,
                    response_serializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.SerializeToString,
            ),
            'OperateBiStreamFlow': grpc.stream_stream_rpc_method_handler(
                    servicer.OperateBiStreamFlow,
                    request_deserializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryRequest.FromString,
                    response_serializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.SerializeToString,
            ),
            'OperateServerStream': grpc.unary_stream_rpc_method_handler(
                    servicer.OperateServerStream,
                    request_deserializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryRequest.FromString,
                    response_serializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.SerializeToString,
            ),
            'OperateClientStream': grpc.stream_unary_rpc_method_handler(
                    servicer.OperateClientStream,
                    request_deserializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryRequest.FromString,
                    response_serializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.SerializeToString,
            ),
            'FileOperateBiStreamFlow': grpc.stream_stream_rpc_method_handler(
                    servicer.FileOperateBiStreamFlow,
                    request_deserializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.FileRequestChunk.FromString,
                    response_serializer=epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'epl.protobuf.v1.GeometryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class GeometryService(object):
    """
    gRPC Interfaces for working with geometry operators
    """

    @staticmethod
    def Operate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/epl.protobuf.v1.GeometryService/Operate',
            epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryRequest.SerializeToString,
            epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OperateBiStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/epl.protobuf.v1.GeometryService/OperateBiStream',
            epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryRequest.SerializeToString,
            epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OperateBiStreamFlow(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/epl.protobuf.v1.GeometryService/OperateBiStreamFlow',
            epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryRequest.SerializeToString,
            epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OperateServerStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/epl.protobuf.v1.GeometryService/OperateServerStream',
            epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryRequest.SerializeToString,
            epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OperateClientStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/epl.protobuf.v1.GeometryService/OperateClientStream',
            epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryRequest.SerializeToString,
            epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FileOperateBiStreamFlow(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/epl.protobuf.v1.GeometryService/FileOperateBiStreamFlow',
            epl_dot_protobuf_dot_v1_dot_geometry__pb2.FileRequestChunk.SerializeToString,
            epl_dot_protobuf_dot_v1_dot_geometry__pb2.GeometryResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)
